@@ -47,13 +47,13 @@ def stop_on_keyboardinterrupt(decorated_fun):
 
 KEYMAPS = collections.defaultdict(
     lambda: {
-        "BTN_LEFT": "🖱️ MOUSE-LEFT",
-        "BTN_MIDDLE": "🖱️ MOUSE-MIDDLE",
-        "BTN_RIGHT": "🖱️ MOUSE-RIGHT",
-        "BTN_EXTRA": "🖱️ MOUSE-EXTRA",
-        "BTN_SIDE": "🖱️ MOUSE-SIDE",
-        "REL_WHEEL_UP": "🖱️ SCROLL-UP",
-        "REL_WHEEL_DOWN": "🖱️ SCROLL-DOWN",
+        "BTN_LEFT": "MOUSE-LEFT",
+        "BTN_MIDDLE": "MOUSE-MIDDLE",
+        "BTN_RIGHT": "MOUSE-RIGHT",
+        "BTN_EXTRA": "MOUSE-EXTRA",
+        "BTN_SIDE": "MOUSE-SIDE",
+        "REL_WHEEL_UP": "SCROLL-UP",
+        "REL_WHEEL_DOWN": "SCROLL-DOWN",
     }
 )
 
@@ -152,7 +152,7 @@ def make_argparser():
  \__|\___||_| |_|_|_|_\_\___| \_, |_|_|_|\___/|_||_|_| \__|\___/|_|
                               |__/
 
-                 ⌨️  Show pressed keys in the terminal 📟
+                 Show pressed keys in the terminal
 useful e.g. to show key presses in an asciinema cast (https://asciinema.org)
 """
         f"""
